==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateHeaderCellUpdatingEventArgsDescription } from "./TemplateHeaderCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
var TemplateHeaderCellUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata, _super);
    function TemplateHeaderCellUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a == null) {
            TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.c(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.g(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.c = function (a) {
    };
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.d = function (a) {
        TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.b(a);
        a.u("TemplateHeaderCellUpdatingEventArgs", function () { return new TemplateHeaderCellUpdatingEventArgsDescription(); });
        a.t("TemplateHeaderCellUpdatingEventArgs", TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.$t = markType(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata, 'TemplateHeaderCellUpdatingEventArgsDescriptionMetadata');
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateHeaderCellUpdatingEventArgsDescriptionMetadata;
}(Base));
export { TemplateHeaderCellUpdatingEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TemplateHeaderCellUpdatingEventArgsDescription } from "./TemplateHeaderCellUpdatingEventArgsDescription";
/**
 * @hidden
 */
var TemplateHeaderCellUpdatingEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata, _super);
    function TemplateHeaderCellUpdatingEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.b = function (a) {
        if (TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a == null) {
            TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.c(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
        }
        if (a.j(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.c = function (a) {
    };
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.d = function (a) {
        TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.b(a);
        a.aa("TemplateHeaderCellUpdatingEventArgs", function () { return new TemplateHeaderCellUpdatingEventArgsDescription(); });
        a.z("TemplateHeaderCellUpdatingEventArgs", TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a);
    };
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.$t = markType(TemplateHeaderCellUpdatingEventArgsDescriptionMetadata, 'TemplateHeaderCellUpdatingEventArgsDescriptionMetadata');
    TemplateHeaderCellUpdatingEventArgsDescriptionMetadata.a = null;
    return TemplateHeaderCellUpdatingEventArgsDescriptionMetadata;
}(Base));
export { TemplateHeaderCellUpdatingEventArgsDescriptionMetadata };
